@@ -10,14 +10,17 @@
 #'   \item{mode:}{
 #'     Predicts the most frequent label. If there are two or more labels tied, randomly selects one per prediction.
 #'     Probabilities correspond to the relative frequency of the class labels in the training set.
+#'     For weighted data, the label(s) with the highest weighted frequency are selected.
 #'   }
 #'   \item{sample:}{
 #'     Randomly predict a label uniformly.
 #'     Probabilities correspond to a uniform distribution of class labels, i.e. 1 divided by the number of classes.
+#'     Weights are ignored, if present.
 #'   }
 #'   \item{weighted.sample:}{
 #'     Randomly predict a label, with probability estimated from the training distribution.
 #'     For consistency, probabilities are 1 for the sampled label and 0 for all other labels.
+#'     For weighted data, sample weights are used to weight the class labels.
 #'   }
 #' }
 #'
@@ -40,7 +43,7 @@ LearnerClassifFeatureless = R6Class("LearnerClassifFeatureless", inherit = Learn
         feature_types = mlr_reflections$task_feature_types,
         predict_types = c("response", "prob"),
         param_set = ps,
-        properties = c("featureless", "twoclass", "multiclass", "missings", "importance", "selected_features"),
+        properties = c("featureless", "twoclass", "multiclass", "missings", "importance", "selected_features", "weights"),
         label = "Featureless Classification Learner",
         man = "mlr3::mlr_learners_classif.featureless",
       )
@@ -67,8 +70,10 @@ LearnerClassifFeatureless = R6Class("LearnerClassifFeatureless", inherit = Learn
 
   private = list(
     .train = function(task) {
-      tn = task$target_names
-      set_class(list(tab = table(task$data(cols = tn)[[1L]]), features = task$feature_names), "classif.featureless_model")
+      weights = NULL
+      counts_table = data.table(truth = task$truth(), weights = private$.get_weights(task, 1.0))[, list(weights = sum(weights)), by = "truth"]
+      tab = set_names(counts_table$weights, counts_table$truth)
+      set_class(list(tab = tab, features = task$feature_names), "classif.featureless_model")
     },
 
     .predict = function(task) {
