@@ -20,7 +20,7 @@ NULL
 
 load_task_iris = function(id = "iris") {
   b = as_data_backend(load_dataset("iris", "datasets"))
-  task = TaskClassif$new(id, b, target = "Species")
+  task = TaskClassif$new(id, b, target = "Species", label = "Iris Flowers")
   b$hash = task$man = "mlr3::mlr_tasks_iris"
   task
 }
