@@ -132,6 +132,11 @@ benchmark = function(design, store_models = FALSE, store_backends = TRUE, encaps
     param_values = map(param_values, function(values) insert_named(learner$param_set$values, values))
     assert_learnable(task, learner, unlist(param_values, recursive = FALSE))
 
+    # check that all row ids of the resampling are present in the task
+    if (resampling$task_row_hash != task$row_hash) {
+      stopf("Resampling '%s' is not instantiated on task '%s'", resampling$id, task$id)
+    }
+
     data.table(
       task = list(task), learner = list(learner), resampling = list(resampling),
       iteration = rep(seq_len(iters), times = n_params),
@@ -141,7 +146,6 @@ benchmark = function(design, store_models = FALSE, store_backends = TRUE, encaps
   })
 
   n = nrow(grid)
-  lgr_threshold = map_int(mlr_reflections$loggers, "threshold")
 
   # set default mode
   set(grid, j = "mode", value = "train")
@@ -186,7 +190,7 @@ benchmark = function(design, store_models = FALSE, store_backends = TRUE, encaps
 
   res = future_map(n, workhorse,
     task = grid$task, learner = grid$learner, resampling = grid$resampling, iteration = grid$iteration, param_values = grid$param_values, mode = grid$mode,
-    MoreArgs = list(store_models = store_models, lgr_threshold = lgr_threshold, pb = pb, unmarshal = unmarshal, callbacks = callbacks)
+    MoreArgs = list(store_models = store_models, lgr_index = lgr::logger_index(), pb = pb, unmarshal = unmarshal, callbacks = callbacks)
   )
 
   grid = insert_named(grid, list(
