@@ -74,13 +74,13 @@ generate_generic_tasks = function(learner, proto) {
   # task with weights
   if ("weights" %in% learner$properties) {
     tmp = proto$clone(deep = TRUE)$cbind(data.frame(weights = runif(n)))
-    tmp$set_col_roles(cols = "weights", roles = "weight")
-    tasks$weights = tmp
+    tmp$set_col_roles(cols = "weights", roles = "weights_learner")
+    tasks$weights_learner = tmp
   }
 
   # task with offset
   if ("offset" %in% learner$properties) {
-    if ("multiclass" %in% tmp$properties) {
+    if ("multiclass" %in% learner$properties && "multiclass" %in% proto$properties) {
       offset_cols = paste0("offset_", proto$class_names)
       # One offset column per class
       offset_data = as.data.frame(
@@ -300,6 +300,7 @@ run_experiment = function(task, learner, seed = NULL, configure_learner = NULL)
 
   # function to collect error message and objects
   err = function(info, ...) {
+    info = gsub("%", "", info)
     info = sprintf(info, ...)
     list(
       ok = FALSE, seed = seed,
@@ -334,6 +335,19 @@ run_experiment = function(task, learner, seed = NULL, configure_learner = NULL)
   # check train
   stage = "train()"
 
+  # enable weights
+  # the next lines are maybe not strictly necessary, but test that the defaults are
+  # what they should be
+  if ("weights" %in% learner$properties) {
+    if (learner$use_weights != "use") {
+      return(err("use_weights != 'use' for learner with property 'weights' on init!"))
+    }
+  } else {
+    if (learner$use_weights != "error") {
+      return(err("use_weights != 'error' for learner without property 'weights' on init!"))
+    }
+  }
+
   ok = suppressWarnings(try(learner$train(task), silent = TRUE))
   if (inherits(ok, "try-error")) {
     return(err(as.character(ok)))
@@ -448,6 +462,63 @@ run_experiment = function(task, learner, seed = NULL, configure_learner = NULL)
     }
   }
 
+  if ("weights" %in% learner$properties) {
+    use_weights = learner$use_weights
+    get_weights = learner$.__enclos_env__$private$.get_weights
+    counter = R6::R6Class("counter", public = list(count = 0, count_up = function(x) self$count = self$count + 1))$new()
+    get_weights_counter = function(...) {
+      counter$count_up()
+      get_weights(...)
+    }
+    on.exit({
+      learner$.__enclos_env__$private$.get_weights = get_weights
+      lockBinding(".get_weights", env = learner$.__enclos_env__$private)
+      learner$use_weights = use_weights
+    })
+
+    unlockBinding(".get_weights", env = learner$.__enclos_env__$private)
+    learner$.__enclos_env__$private$.get_weights = get_weights_counter
+
+    learner$use_weights = "use"
+    suppressWarnings(learner$train(task))
+    if (counter$count == 0) {
+      return(err("get_weights was not called"))
+    }
+
+    learner$use_weights = "ignore"
+    suppressWarnings(learner$train(task))
+    if (counter$count == 0) {
+      return(err("get_weights was not called. It should be called even when use_weights = 'ignore'"))
+    }
+
+    learner$.__enclos_env__$private$.get_weights = get_weights
+    lockBinding(".get_weights", env = learner$.__enclos_env__$private)
+    learner$use_weights = use_weights
+    on.exit()
+  }
+
+  # predict_newdata_fast method
+  if (startsWith(task$id, "feat_all") && exists("predict_newdata_fast", learner) && learner$predict_type == "prob") {
+
+    prediction = suppressWarnings(try(learner$predict_newdata_fast(task$data()), silent = TRUE))
+
+    if (inherits(prediction, "try-error")) {
+      ok = prediction
+      prediction = NULL
+      return(err(c("predict_newdata_fast failed: ", as.character(ok))))
+    }
+
+    msg = checkmate::check_list(prediction)
+    if (!isTRUE(msg)) {
+      return(err("predict_newdata_fast does not return a list"))
+    }
+
+    msg = checkmate::check_names(names(prediction), subset.of = mlr3::mlr_reflections$learner_predict_types[[learner$task_type]][[learner$predict_type]])
+    if (!isTRUE(msg)) {
+      return(err("Names of list returned by predict_newdata_fast do not match learner predict_types: %s", str_collapse(names(prediction))))
+    }
+  }
+
   return(list(ok = TRUE, learner = learner, prediction = prediction, error = character(), seed = seed))
 }
 
@@ -510,14 +581,14 @@ run_autotest = function(learner, N = 30L, exclude = NULL, predict_types = learne
         learner$quantiles = 0.5
       }
 
-      run = run_experiment(task, learner)
+      run = run_experiment(task, learner, NULL, configure_learner)
       if (!run$ok) {
         return(run)
       }
 
       # re-run task with same seed for feat_all
       if (startsWith(task$id, "feat_all")) {
-        repeated_run = run_experiment(task, learner, seed = run$seed)
+        repeated_run = run_experiment(task, learner, seed = run$seed, configure_learner)
 
         if (!repeated_run$ok) {
           return(repeated_run)
