@@ -9,9 +9,3 @@
     return(get(name, envir = x))
   stop("R6 class ", paste0(class(x), collapse = "/") ," does not have slot '", name, "'!")
 }
-
-private = function(x) {
-  if (!R6::is.R6(x))
-    stop("Expected R6 class")
-  x$.__enclos_env__[["private"]]
-}
