@@ -10,6 +10,17 @@ expect_hash_changes = function(x) {
   x$id = id_before
   expect_identical(x$id, id_before)
   expect_identical(x$hash, hash_before)
+  if ("use_weights" %in% names(x)) {
+    use_weights_before = x$use_weights
+    x$use_weights = "ignore"
+    expect_false(identical(x$use_weights, use_weights_before))
+    if (!is.na(hash_before)) {
+      expect_false(identical(x$hash, hash_before))
+    }
+    x$use_weights = use_weights_before
+    expect_identical(x$use_weights, use_weights_before)
+    expect_identical(x$hash, hash_before)
+  }
 }
 
 test_that("task$hash", {
